@@ -32,7 +32,7 @@ def write(text, *args, style=Style.INFORM):
 
 def color_print(text, color=None):
     if color:
-        print(color + text + Colors.ENDC)
+        print(f'{color}{text}{Colors.ENDC}')
     else:
         print(text)
 
